globalVariables(c("zone", "region", "parent_class", "child_class",
  "collection", "property", "table_name", "unit", "child_name",
  "parent_name", "child_group", "phase_id", "timeslice", "band",
  ".", "period_type_id", "position", "period_offset", "child_category",
  "child_collection", "is_summary", "count_band", "count_sample",
  "count_timeslice", "filename", "scenario", "key", "value",
  "interval_id", "interval_to_id", "db", "period_id", "time_from",
  "time_to", "Version", "rplexos", "d", "error", "interval",
  "tables", "properties", "i", "phase", "timestep", "name", "type",
  "folder", "class_group"))
